.. _api_reference_toplevel:

API Reference
=============

Version
-------

.. py:data:: psec.__version__

   Current python_secrets version.

psec.google_oauth2
------------------

.. automodule:: psec.google_oauth2
   :members:
   :undoc-members:
   :special-members:
   :noindex:


psec.secrets_environment
------------------------

.. automodule:: psec.secrets_environment
   :members:
   :undoc-members:
   :special-members:
   :noindex:

psec.utils
----------

.. automodule:: psec.utils
   :members:
   :undoc-members:
   :special-members:
   :noindex:

